@@ -4,11 +4,10 @@
 # TODO(Jflesch): PEP8 ...
 # flake8: noqa
 
+import pycountry
 import re
 import sys
 
-from paperwork_backend.util import find_language
-
 
 DEFAULT_DOWNLOAD_URI = (
     "https://download.openpaper.work/windows/x86/paperwork-master-latest.zip"
@@ -386,7 +385,7 @@ FunctionEnd
 
 Function un.onInit
 !insertmacro MUI_UNGETLANGUAGE
-  MessageBox MB_ICONQUESTION|MB_YESNO|MB_DEFBUTTON2 "Are you sure you want to deinstall $(^Name) ? (your documents won't be deleted)" IDYES +2
+  MessageBox MB_ICONQUESTION|MB_YESNO|MB_DEFBUTTON2 "Are you sure you want to uninstall $(^Name) ? (your documents won't be deleted)" IDYES +2
   Abort
 FunctionEnd
 
@@ -420,6 +419,33 @@ Section Uninstall
 SectionEnd
 """
 
+def find_language(lang_str):
+    lang_str = lang_str.lower()
+    if "_" in lang_str:
+        lang_str = lang_str.split("_")[0]
+    print("System language: {}".format(lang_str))
+
+    attrs = (
+        'iso_639_3_code',
+        'iso639_3_code',
+        'iso639_2T_code',
+        'iso639_1_code',
+        'terminology',
+        'bibliographic',
+        'alpha_3',
+        'alpha_2',
+        'alpha2',
+        'name',
+    )
+    for attr in attrs:
+        try:
+            r = pycountry.pycountry.languages.get(**{attr: lang_str})
+            if r is not None:
+                return r
+        except (KeyError, UnicodeDecodeError):
+            pass
+    raise Exception("Unable to find language !")
+
 
 def get_lang_infos(lang_name):
     if isinstance(lang_name, dict):
