@@ -90,7 +90,6 @@ Main features are:
         "openpaperwork-gtk",
         "pycountry",
         "pyocr >= 0.3.0",
-        "python-dateutil",
         "python-Levenshtein",
         "pyxdg >= 0.25",
         "paperwork-backend>={}".format(version),
@@ -118,6 +117,7 @@ else:
         'libgdk-3-0.dll',
         'libgdk_pixbuf-2.0-0.dll',
         'libgtk-3-0.dll',
+        'libhandy-1-0.dll',
         'libinsane.dll',
         'libinsane_gobject.dll',
         'libnotify-4.dll',
@@ -165,6 +165,7 @@ else:
         "GModule-2.0",
         "GObject-2.0",
         "Gtk-3.0",
+        "Handy-1",
         "HarfBuzz-0.0",
         "Notify-0.7",
         "Pango-1.0",
@@ -184,16 +185,13 @@ else:
         common_include_files.append((fullpath, subpath))
 
     common_packages = [
-        # XXX(Jflesch): known bug in cx_freeze
-        'appdirs',
-        'packaging',
-
         "gi",   # always seems to be needed
         "cairo",   # Only needed (for foreign structs) if no "import cairo"s
 
         # XXX(Jflesch): bug ?
         "pyocr",
         "pyocr.libtesseract",
+        "setuptools",
 
         "openpaperwork_core",
         "openpaperwork_gtk",
